/**
 *
 * @param el 实列对象
 * @param prop 获取的属性
 * @returns {number} 属性值
 */
export function getStyle(el,prop) {
    return parseInt(window.getComputedStyle(el, null)[prop])
}

/**
 *
 * @param fn 执行函数
 * @param delay 时间间隔
 * @param immediate true，在开始时先执行一次fn
 * @return {(function(): void)|*}
 */
export function debounce(fn, delay=500, immediate= false) {
    let timer = null;

    return function () {
         let context = this;
         let args = arguments;
         clearTimeout(timer);
         if (immediate && timer === null) {
             fn.apply(context,args);
             timer = 0;
         }else {
             timer = setTimeout(function () {
                 fn.apply(context, args);
                 timer = null;
             }, delay);
         }
     }
}

/**
 *
 * @param fn 执行函数
 * @param delay 时间间隔
 * @returns {(function(): void)|*}
 */
export function throttle(fn, delay=500) {
    let timer = null;
    let timeStamp = new Date();
    return function () {
        let context = this;
        let args = arguments;
        if (new Date() - timeStamp > delay) {
            timeStamp = new Date();
            timer = setTimeout(function () {
                fn.apply(context, args);
            },delay)
        }
    }
}

export function hasClass(el, cls){
    let elClass = el.className,//获取 class 内容.
        elClassList = elClass.split(/\s+/);//通过split空字符将cls转换成数组.
    let result = false
    elClassList.forEach((classItem) => {
        if (classItem === cls) {
            result = true
        }
    })

    return result;
}
export function addClass (el, cls) {
    if (!el) return
    let curClass = el.className
    let classes = (cls || '').split(' ')

    for (let i = 0, j = classes.length; i < j; i++) {
        let clsName = classes[i]
        if (!clsName) continue
        if (!hasClass(el, clsName) && el.classList) {
            el.classList.add(clsName)
        }
    }
}

export function removeClass (el, cls) {
    if (!el || !cls) return
    let classes = cls.split(' ')
    let curClass = ' ' + el.className + ' '

    for (let i = 0, j = classes.length; i < j; i++) {
        let clsName = classes[i]
        if (!clsName) continue
        if (hasClass(el, clsName)) {
            el.classList.remove(clsName)
        }
    }

}
const LiTools = {
    getStyle,
    debounce,
    throttle,
    addClass,
    removeClass,
    hasClass
}
export default LiTools